==> openjfx_11.0.2+1.orig.tar.xz: openjdk-jfx-11.0.2-1/modules/javafx.web/src/main/native/Source/JavaScriptCore/assembler/AllowMacroScratchRegisterUsageIf.h <==
/*
 * Copyright (C) 2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(ASSEMBLER)

#include "MacroAssembler.h"

namespace JSC {

class AllowMacroScratchRegisterUsageIf {
public:
    AllowMacroScratchRegisterUsageIf(MacroAssembler& masm, bool allowIfTrue)
        : m_masm(masm)
        , m_allowIfTrue(allowIfTrue)
        , m_oldValueOfAllowScratchRegister(masm.m_allowScratchRegister)
    {
        if (m_allowIfTrue)
            masm.m_allowScratchRegister = true;
    }

    ~AllowMacroScratchRegisterUsageIf()
    {
        if (m_allowIfTrue)
            m_masm.m_allowScratchRegister = m_oldValueOfAllowScratchRegister;
    }

private:
    MacroAssembler& m_masm;
    bool m_allowIfTrue;
    bool m_oldValueOfAllowScratchRegister;
};

} // namespace JSC

#endif // ENABLE(ASSEMBLER)

==> openjfx_11.0.7+0.orig.tar.xz: openjdk-jfx-11.0.7-0/modules/javafx.web/src/main/native/Source/JavaScriptCore/assembler/AllowMacroScratchRegisterUsageIf.h <==
/*
 * Copyright (C) 2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(ASSEMBLER)

#include "MacroAssembler.h"

namespace JSC {

class AllowMacroScratchRegisterUsageIf {
public:
    AllowMacroScratchRegisterUsageIf(MacroAssembler& masm, bool allowIfTrue)
        : m_masm(masm)
        , m_allowIfTrue(allowIfTrue)
        , m_oldValueOfAllowScratchRegister(masm.m_allowScratchRegister)
    {
        if (m_allowIfTrue) {
#if CPU(ARM64)
            if (!m_oldValueOfAllowScratchRegister)
                m_masm.invalidateAllTempRegisters();
#endif
            masm.m_allowScratchRegister = true;
        }
    }

    ~AllowMacroScratchRegisterUsageIf()
    {
        if (m_allowIfTrue)
            m_masm.m_allowScratchRegister = m_oldValueOfAllowScratchRegister;
    }

private:
    MacroAssembler& m_masm;
    bool m_allowIfTrue;
    bool m_oldValueOfAllowScratchRegister;
};

} // namespace JSC

#endif // ENABLE(ASSEMBLER)
